@@ -13,6 +13,7 @@ chars3Re2 = regex.compile("[\u2000-\u200F]")
 chars3Re3 = regex.compile("\u007F|[\u0080-\u00A0]")
 quotesRegex = regex.compile("(?P<start>[[:alpha:]])\'\'(?P<end>(s|S|t|T|m|M|d|D|re|RE|ll|LL|ve|VE|em|EM)\W)")
 collapse_spaced_entities = regex.compile('([&][ ]*[#][ ]*)([0-9]{2,6})([ ]*[;])')
+html_tags_regex = re.compile('<.*?>') 
 
 #https://en.wikipedia.org/wiki/CJK_Symbols_and_Punctuation
 cjk_langs = [
@@ -649,7 +650,6 @@ def getNormalizedPunctReplacements(lang):
             " ]": "]",
             #            " \""      :       "\"",          
             " ...": "...",
-
             "( ": "(",
             "{ ": "{",
             "[ ": "["
@@ -657,6 +657,7 @@ def getNormalizedPunctReplacements(lang):
 
     else:
         replacements = {
+            " .":".",
             " !": "!",
             " ?": "?",
             " :": ":",
@@ -743,9 +744,10 @@ def normalize(text, lang, punct_rep, punct_pattern):
     normalized_text = chars3Re2.sub(replace_chars3, normalized_text)
     normalized_text = chars3Re3.sub(replace_chars3, normalized_text)
     normalized_text = quotesRegex.sub("\g<start>\'\g<end>", normalized_text)
-    normalized_text_with_normalized_punct = punct_pattern.sub(lambda m: punct_rep[re.escape(m.group(0))], normalized_text)
+    collapsed_spaces_with_collapsed_spaces = re.sub('\s+', ' ', normalized_text)  # Collapse multiple spaces
+    normalized_text_with_normalized_punct = punct_pattern.sub(lambda m: punct_rep[re.escape(m.group(0))], collapsed_spaces_with_collapsed_spaces)
 
-    collapsed_spaces = re.sub('\s+', ' ', normalized_text_with_normalized_punct)  # Collapse multiple spaces
+    collapsed_spaces = re.sub('\s+', ' ', normalized_text_with_normalized_punct)  # Collapse multiple spaces again
     collapsed_entities = collapse_spaced_entities.sub("&#\\2;", collapsed_spaces)
 
     return collapsed_entities.strip(" \n")
@@ -820,3 +822,7 @@ def ortho_detok_fix(text, replacements, detoks):
         fixed_text = text
 
     return fixed_text
+
+
+def remove_html_tags(text):
+    return re.sub(html_tags_regex, ' ', text).strip()
\ No newline at end of file
